@@ -15,12 +15,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+import textwrap
 from collections import Counter, OrderedDict
 from difflib import unified_diff
 from itertools import combinations
 from operator import attrgetter
 from pathlib import Path
-import textwrap
 
 import click
 from boltons.cacheutils import cachedproperty
@@ -31,7 +31,6 @@ from .colorize import choice_style, subtitle_style
 from .mailbox import open_box
 from .strategy import apply_strategy
 
-
 # Reference all tracked statistics and their definition.
 STATS_DEF = OrderedDict(
     [
@@ -124,6 +123,12 @@ class DuplicateSet:
         """
         self.hash_key = hash_key
 
+        # Mails selected after application of selection strategy.
+        self.selection = set()
+
+        # Mails discarded after application of selection strategy.
+        self.discard = set()
+
         # Global config.
         self.conf = conf
 
@@ -239,10 +244,10 @@ class DuplicateSet:
             )
         )
 
-    def select_candidates(self):
-        """Returns the list of duplicates selected for action.
+    def categorize_candidates(self):
+        """Process the list of duplicates for action.
 
-        Run preliminary checks and return the candidates fitting the configured
+        Run preliminary checks and fill the corresponding sets fitting the configured
         strategy and safety checks.
         """
         # Fine-grained checks on mail differences.
@@ -285,11 +290,22 @@ class DuplicateSet:
             self.stats["set_skipped_strategy"] += 1
             return
 
+        # Duplicate sets matching none are skipped altogether.
+        if candidate_count == 0:
+            logger.warning(
+                f"Skip set: No mail within were selected. "
+                "The strategy criterion was not able to select some."
+            )
+            self.stats["mail_skipped"] += self.size
+            self.stats["set_skipped_strategy"] += 1
+            return
+
         logger.info(f"{candidate_count} mail candidates selected for action.")
         self.stats["mail_selected"] += candidate_count
         self.stats["mail_discarded"] += self.size - candidate_count
         self.stats["set_deduplicated"] += 1
-        return selected
+        self.selection = selected
+        self.discard = self.pool.difference(selected)
 
 
 class Deduplicate:
@@ -312,6 +328,9 @@ class Deduplicate:
         # Mails selected after application of selection strategy.
         self.selection = set()
 
+        # Mails discarded after application of selection strategy.
+        self.discard = set()
+
         # Global config.
         self.conf = conf
 
@@ -376,8 +395,8 @@ class Deduplicate:
 
         self.stats["mail_hashes"] += len(self.mails)
 
-    def select_all(self):
-        """Gather the final selection of mails from each duplicate set.
+    def build_sets(self):
+        """Build the selected and discarded sets from each duplicate set.
 
         We apply the selection strategy one duplicate set at a time to keep memory
         footprint low and make the log easier to read.
@@ -406,18 +425,17 @@ class Deduplicate:
                 self.stats["mail_unique"] += 1
                 self.stats["mail_selected"] += 1
                 self.stats["set_single"] += 1
-                candidates = mail_set
+                self.selection.update(mail_set)
 
             # We need to resort to a selection strategy to discriminate mails
             # within the set.
             else:
                 duplicates = DuplicateSet(hash_key, mail_set, self.conf)
-                candidates = duplicates.select_candidates()
+                duplicates.categorize_candidates()
                 # Merge duplicate set's stats to global stats.
                 self.stats += duplicates.stats
-
-            if candidates:
-                self.selection.update(candidates)
+                self.selection.update(duplicates.selection)
+                self.discard.update(duplicates.discard)
 
     def close_all(self):
         """ Close all open boxes. """
